Contributing Guidelines
=======================

Contributions to the project are welcome.
Please refer to the `CONTRIBUTING.md <https://github.com/DOI-USGS/hyswap/blob/main/CONTRIBUTING.md>`_ file for more detailed information on the various ways you can contribute.
